<!--
SPDX-FileCopyrightText: 2021-2022 Jens Meisner <jens.meisner@ose-germany.de>

SPDX-License-Identifier: CC-BY-SA-4.0
-->

# README-Struktur

## Beschreibung

Damit das Repository in seinem Inhalt und in seiner Struktur besonders schnell erfasst werden kann, werden hier die Qualitätsmerkmale beschrieben.

Die Readme-Struktur des [Fabulasers](https://github.com/fab-machines/Fabulaser-Mini) ist dabei eine gute Orientierung.

Innerhalb der README des Repos sollten in jedem Fall folgende Kategorien mit Inhalt gefüllt werden:

1. Kurzbeschreibung der OSH (analog "Katalogbeschreibung")  
2. Bild(er) der OSH
3. Spezifikation/Features (Datenblatt-Information, Besonderheiten, ggf. Maße)
4. Linkbaum (Links zu den wichtigesten Repo-Dokumenten, damit man sich einfach zurechtfindet (Designfiles, Assembly guideline, BoM) etwa so wie in der Kategorie _Guides_))
5. Lizenz (in Worten was womit lizensiert ist (unterteilt in Hardware, Software/ Firmware, Dokumentation)  

# Checkliste für das gesamte Repository

## Lizenzablage

- [ ] gemäß REUSE
- [ ] Vorhanden für OSH
- [ ] Vorhanden für Dokumentation
- [ ] Vorhanden für Software/ Firmware
- [ ] Die 3 Copyrightzeilen zur Lizenz-zuordnung in jedem Dokument vorhanden

## BoM Inhalt

- [ ] Die BoM ist vollständig, alle verwendeten Teile sind aufgelistet
- [ ] Die Bezeichnungen der Teile sind eindeutig und unmissverständlich
- [ ] Die Mengen sind korrekt
- [ ] Die Materialparameter sind spezifiziert (nice to have)
- [ ] BOM per Step  (nice to have) für jeden Schritt in der Assembly Guideline eine seperate BOM beschreiben
- [ ] editierbare BOM

### BOM Struktur (Spalten)

- [ ] Induviduelle Teilenummern/Hyperlinks stimmen mit Assembly Guideline überein
- [ ] src files werden verlinkt (optional)
- [ ] Quantität
- [ ] Bezugsquellen werden genannt
- [ ] Bestellnummer vom jeweiligen Lieferanten
- [ ] Name des Teils (z.B.Schraube)
- [ ] spezifischer Name (z.B. M8x140mm)
- [ ] Notizen (z.B. sollte aus rostfreiem Stahl sein)
- [ ] Herkunft des Teils (z.B. Hamburg, Danzig, )

## Assembly Guideline 

- [ ] Werkzeuge werden gelistet
- [ ] Konsistent
- [ ] Hyperlinks vorhanden
- [ ] Bilder erklären durchführung
- [ ] Unmissverständliche Dokumentation
- [ ] Gefahrenhinweise vorhanden
- [ ] Toleranzen der Produktionsmaschienen sind angegeben
- [ ] Oberflächen Behandlungen, nacharbeiten von Teilen, zB. aus dem 3D Druck oder der Fräse

## `okh.toml` Datei

- [ ] Mindestens die notwendigen Felder sind ausgefüllt
- [ ] Im Root-Folder des Repositories abgespeichert

## Formale Aspekte

- [ ] Markdown korrekt verwendet
- [ ] REUSE/Linter Prüfung bestanden

## Darstellung für Nutzende (kein notwendiges Kriterium)

- [ ] Dokumentationshandbuch wurde erstellt (pdf/html)

## Wiederholbarkeitsgüte (kein notwendiges Kriterium)

- [ ] Replizierbar durch gleiche Workshopleitung
- [ ] Wiederholbar durch andere Workshopleitung

## Dokumentation des Workshops

- [ ] Existiert
- [ ] Fabrikationsschritte zeitl. beschrieben
- [ ] Raumanforderungen beschrieben
- [ ] Werkzeugmenge beschrieben
- [ ] Teilnahmevorraussetzungen beschrieben
- [ ] Workshopinfo Datenblatt abgelegt

## Designfiles

- [ ] CAD Files als STL verfuegbar
- [ ] CADs auch als Bild oder in PDF einsehbar
- [ ] Die Designfiles sind vollständig; 
- [ ] Die Designfiles liegen als editierbare "source"-Daten vor (STL oder STEP sind keine source formate)
- [ ] Die genutzen Software Tools für die erstellten Dateien sind mit angegeben 
- [ ] Dimensionen sind mit angegeben
- [ ] Alle für die Herstellung notwendigen Infos sind vorhanden
- [ ] Die Ansicht der Daten ist sinnvoll skaliert
- [ ] Teilenummer ("ID-Nummer") stimmt mit BoM und Assembly Guideline überein (konsistente Nutzung der "ID")
- [ ] Schaltkreise auf Platinen (PCB) als KiCad gesondert in Ordner `/elec` abgespeichert
 
## Software und Firmware (falls vorhanden)

- [ ] Firmware ist im Repository abgelegt, oder verlinkt, wenn sie zur Verwendung der OSH notwendig ist
- [ ] Eine Guideline für diese Firmware bzw. Software wurde erstellt

## Ordnerstruktur

- [ ] gemäß [Template](#OHLOOM)
- [ ] Subrepositories für Binary Files (z.B. unter `/res/assets/`)

# OHLOOM

[![License: CC BY-SA 4.0](
https://img.shields.io/badge/License-CC%20BY--SA%204.0-blue.svg)](
https://creativecommons.org/licenses/by-sa/4.0/)
[![REUSE status](
https://api.reuse.software/badge/gitlab.com/OSEGermany/ohloom)](
https://api.reuse.software/info/gitlab.com/OSEGermany/ohloom)
[![made-with-Markdown](
https://img.shields.io/badge/Made%20with-Markdown-1f425f.svg)](
http://commonmark.org)
[![made-with-OpenSCAD](
https://img.shields.io/badge/Made%20with-OpenSCAD-orange.svg)](
http://openscad.org/)

**O**pen **H**ardware **Loom**
(GER: Webstuhl)

You may want to see [the original project Wiki](
https://wiki.opensourceecology.de/Open_Hardware-Webstuhl_%E2%80%93_OHLOOM),
though this repo practically makes the Wiki version obsolete,
as it contains improvements,
and further development will happen here.

## Guides

| [User Guide][UserGuideEn] | [Assembly Guide][AssemblyGuideEn] |
| :----: | :----: |
| [![][UserGuideImg]][UserGuideEn] | [![][AssemblyGuideImg]][AssemblyGuideEn] |
| [ENG][UserGuideEn] / [GER][UserGuideDe] | [ENG][AssemblyGuideEn] / [GER][AssemblyGuideDe] |

[UserGuideImg]: Documentation/User_Guide/User_Guide.jpg
[UserGuideEn]: Documentation/User_Guide/UserGuide.md
[UserGuideDe]: Documentation/User_Guide/UserGuide_de.md
[AssemblyGuideImg]: Documentation/Assembly_Guide/Assembly_Guide.jpg
[AssemblyGuideEn]: Documentation/Assembly_Guide/AssemblyGuide.md
[AssemblyGuideDe]: Documentation/Assembly_Guide/AssemblyGuide_de.md

## Plans for the Parts

The 3D plans for the parts of the loom
are available as source files in the OpenSCAD format.
Alongside you will find read-only versions as generated STL files
and sometimes technical drawings as PDFs.

You will find all these in this repository in the folders
[3DParts/](./3DParts/) and
[WoodParts/](./WoodParts/).
